%define anolis_release 1

%define systemdpost(pkgname, svcname) \
%post -n %1 \
%systemd_post %2 %3

%define systemdpreun(pkgname, svcname) \
%preun -n %1 \
%systemd_preun %2 %3

%define systemdpostun(pkgname, svcname) \
%postun -n %1 \
%systemd_postun %2 %3

Name:             initscripts
Summary:          basic legacy sysv init scripts used during a boot of the system
Version:          10.19
Release:          %{anolis_release}%{?dist}

License:          GPLv2

URL:              https://github.com/fedora-sysv/initscripts
Source:           https://github.com/fedora-sysv/initscripts/archive/%{version}/%{name}-%{version}.tar.gz

Requires:         bash filesystem >= 3 coreutils gawk 
Requires:         findutils grep procps-ng setup systemd util-linux
Requires:         chkconfig initscripts-service initscripts-rename-device

Requires(pre):    shadow-utils
Requires(post):   coreutils

BuildRequires:    filesystem >= 3 git gcc make setup pkgconfig
BuildRequires:    gettext glib2-devel popt-devel systemd

%{?systemd_requires}
BuildRequires:    systemd

Obsoletes:        %{name}            < 10.16-1

%description
This package provides basic support for legacy sysv init scripts, and some
other legacy tools & utilities.

%package -n initscripts-rename-device
Summary:          A ultility helper program for Udev that provides network interface naming

Requires:         bash filesystem >= 3 coreutils gawk 

%description -n initscripts-rename-device
This package provides a ultility helper program for Udev that provides network interface naming.

%package -n initscripts-service
Summary:          Support for service command
BuildArch:        noarch

Requires:         bash filesystem >= 3 coreutils gawk 
Requires:         systemd

Provides:         /sbin/service

%description -n initscripts-service
'service' command is provided by this package.

%package -n network-scripts
Summary:          Legacy scripts for manipulating of network devices
Requires:         %{name} = %{version}-%{release}

Requires:         bash filesystem >= 3 coreutils gawk 
Requires:         bc dbus dbus-tools gawk grep hostname iproute ipcalc
Requires:         kmod procps-ng sed systemd

Requires(post):   chkconfig
Requires(preun):  chkconfig

Requires(post):   %{_sbindir}/update-alternatives
Requires(postun): %{_sbindir}/update-alternatives

Obsoletes:        %{name}            < 9.82-2

Provides:         deprecated()

%description -n network-scripts
The network-scripts package contains legacy scripts for manipulating network 
devices. It provides a legacy version of 'network' service. This package 
contains the legacy scripts for activating and deactivating most network 
interfaces. 
The 'network' service is enabled by default after installation of 
this package. If the network-scripts are installed alongside NetworkManager, 
then the ifup/ifdown commands from network-scripts will be ignored.

If both network-scripts and NetworkManager are both installed and the user wants to 
use ifup/ifdown from NetworkManager primarily, they must execute the command 
 $ update-alternatives --config ifup

Please be aware that running the above command will also deactivate the 'network' 
service.

%package -n netconsole-service
Summary:          Service for initializing of network console logging
Requires:         %{name} = %{version}-%{release}
BuildArch:        noarch

Requires:         bash filesystem >= 3 coreutils gawk 
Requires:         glibc-common iproute iputils kmod sed util-linux

Obsoletes:        %{name}            < 9.82-2

%description -n netconsole-service
This package provides a service called 'netconsole' which allows loading of the 
netconsole kernel module with the configured parameters. The netconsole kernel 
module itself then enables logging of kernel messages over the network.

%package -n readonly-root
Summary:          Service for configuring read-only root support
Requires:         %{name} = %{version}-%{release}
BuildArch:        noarch

Requires:         bash filesystem >= 3 coreutils gawk 
Requires:         cpio findutils hostname iproute ipcalc util-linux

Obsoletes:        %{name}            < 9.82-2

%description -n readonly-root
This package provides a script and configuration file for configuring read-only 
root support. After installation, additional configuration is required.

Please note that the readonly-root package is considered deprecated with limited 
support. Instead, you can use systemd-volatile-root functionality.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -S git

%build
%make_build PYTHON=%{__python3}

%install
%make_install

%find_lang %{name}

rm -f %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/ifup-ctc

install -m 0755 -d %{buildroot}%{_docdir}/network-scripts

ln -s  %{_docdir}/%{name}/sysconfig.txt %{buildroot}%{_docdir}/network-scripts/
ln -sr %{_mandir}/man8/ifup.8           %{buildroot}%{_mandir}/man8/ifdown.8

touch %{buildroot}%{_sbindir}/ifup %{buildroot}%{_sbindir}/ifdown

%generate_compatibility_deps

%post -n network-scripts
chkconfig --add network > /dev/null 2>&1 || :

for ifname in ifup ifdown; do
    [ -L %{_sbindir}/$ifname ]   || rm -f %{_sbindir}/$ifname
done

%{_sbindir}/update-alternatives --install %{_sbindir}/ifup   ifup   %{_sysconfdir}/sysconfig/network-scripts/ifup 90 \
                                --slave   %{_sbindir}/ifdown ifdown %{_sysconfdir}/sysconfig/network-scripts/ifdown \
                                --initscript network

%systemdpostun readonly-root readonly-root.service
%systemdpreun  readonly-root readonly-root.service
%systemdpost   readonly-root readonly-root.service

%systemdpostun netconsole-service netconsole.service
%systemdpreun  netconsole-service netconsole.service
%systemdpost   netconsole-service netconsole.service

%systemdpostun %{name} import-state.service loadmodules.service
%systemdpreun  %{name} import-state.service loadmodules.service
%systemdpost   %{name} import-state.service loadmodules.service

%preun -n network-scripts
if [ $1 -eq 0 ]; then
  chkconfig --del network > /dev/null 2>&1 || :
  %{_sbindir}/update-alternatives --remove ifup %{_sysconfdir}/sysconfig/network-scripts/ifup
fi

%files -f %{name}.lang
%dir %{abidir}
%{_mandir}/man1/*
%{_prefix}/lib/systemd/system/loadmodules.service
%{_prefix}/lib/systemd/system/import-state.service
%{_libexecdir}/loadmodules
%{_libexecdir}/import-state
%{_sbindir}/genhostid
%{_sbindir}/consoletype
%{abidir}/*-option.list
%{_bindir}/*
%{_sysconfdir}/init.d
%{_sysconfdir}/rc[0-6].d
%{_sysconfdir}/rc.d/init.d/functions
%dir %{_libexecdir}/%{name}/legacy-actions
%dir %{_libexecdir}/%{name}
%dir %{_sysconfdir}/sysconfig/modules
%dir %{_sysconfdir}/sysconfig/console
%dir %{_sysconfdir}/rc.d/rc[0-6].d
%dir %{_sysconfdir}/rc.d/init.d
%dir %{_sysconfdir}/rc.d
%license COPYING
%doc doc/sysconfig.txt

%files -n initscripts-rename-device
%{_udevrulesdir}/*
%{_prefix}/lib/udev/rename_device

%files -n initscripts-service
%{_mandir}/man8/service.*
%{_sbindir}/service
%dir %{_libexecdir}/%{name}/legacy-actions
%dir %{_libexecdir}/%{name}

%files -n network-scripts
%{_docdir}/network-scripts/*
%{_mandir}/man8/usernetctl.*
%{_mandir}/man8/ifdown.*
%{_mandir}/man8/ifup.*
%attr(4755,root,root) %{_sbindir}/usernetctl
%ghost                %{_sbindir}/ifdown
%ghost                %{_sbindir}/ifup
%{_sysconfdir}/sysconfig/network-scripts/*
%config(noreplace)    %{_sysconfdir}/sysconfig/network-scripts/ifcfg-lo
%{_sysconfdir}/rc.d/init.d/network
%dir %{_sysconfdir}/sysconfig/network-scripts
%doc doc/examples/

%files -n netconsole-service
%{_prefix}/lib/systemd/system/netconsole.service
%{_libexecdir}/netconsole
%config(noreplace) %{_sysconfdir}/sysconfig/netconsole

%files -n readonly-root
%{_prefix}/lib/systemd/system/readonly-root.service
%{_libexecdir}/readonly-root
%config(noreplace) %{_sysconfdir}/sysconfig/readonly-root
%config(noreplace) %{_sysconfdir}/statetab
%config(noreplace) %{_sysconfdir}/rwtab
%dir %{_sharedstatedir}/stateless/writable
%dir %{_sharedstatedir}/stateless/state
%dir %{_sharedstatedir}/stateless

%files doc
%doc README.md

%changelog
* Wed Feb 28 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 10.19-1
- update to 10.19

* Mon Apr 10 2023 zhonglingh <zhonglingh@linux.alibaba.com> - 10.17-4
- refactor rpm spec file

* Wed Jan 04 2023 happy_orange <songnannan@linux.alibaba.com> - 10.17-3
- add doc package

* Wed Oct 26 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 10.17-2
- optimise spec file

* Fri Sep 23 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 10.17-1
- update to 10.17

* Tue Mar 08 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 10.16-1
- init from upstream 10.16
